import { BadRequestException, Injectable } from "@nestjs/common";
import * as argon from "argon2";
// biome-ignore lint/style/useImportType: used by Next.js
import { ConfigService } from "@nestjs/config";

@Injectable()
export class CredentialsService {

	constructor(private configService: ConfigService) {
	}

	async hash(plaintextPassword: string) {
		if (plaintextPassword.length < 6) throw new BadRequestException("Password is not strong enough !")
		return argon.hash(Buffer.from(plaintextPassword), {
			secret: this.configService.get("APP_HASH_SECRET"),
		})
	}

	async check(plaintextPassword: string, hashedPassword: string) {
		return argon.verify(hashedPassword, Buffer.from(plaintextPassword), {
			secret: this.configService.get("APP_HASH_SECRET"),
		})
	}
}
